==> cfripper-0.7.0.tar.gz: cfripper-0.7.0/tests/test_rules_sqs_policy_public.py <==
"""
Copyright 2018 Skyscanner Ltd

Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed
under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
CONDITIONS OF ANY KIND, either express or implied. See the License for the
specific language governing permissions and limitations under the License.
"""


import pytest
import os
import pycfmodel

from cfripper.rules.SQSQueuePolicyPublicRule import SQSQueuePolicyPublicRule
from cfripper.model.utils import convert_json_or_yaml_to_dict
from cfripper.model.result import Result
from cfripper.model.rule_processor import Rule


class TestSQSQueuePolicyPublicRule:
    @pytest.fixture(scope="class")
    def template(self):
        dir_path = os.path.dirname(os.path.realpath(__file__))
        with open(f"{dir_path}/test_templates/sqs_policy_public.json") as cf_script:
            cf_template = convert_json_or_yaml_to_dict(cf_script.read())
        return pycfmodel.parse(cf_template)

    def test_public(self, template):
        result = Result()
        rule = SQSQueuePolicyPublicRule(None, result)

        rule.invoke(template.resources, template.parameters)

        assert not result.valid
        assert len(result.failed_rules) == 4
        assert result.failed_rules[0]["reason"] == "SQS Queue policy QueuePolicyPublic1 should not be public"
        assert result.failed_rules[1]["reason"] == "SQS Queue policy QueuePolicyPublic2 should not be public"
        assert result.failed_rules[2]["reason"] == "SQS Queue policy QueuePolicyPublic3 should not be public"
        assert result.failed_rules[3]["reason"] == "SQS Queue policy QueuePolicyPublic4 should not be public"

        assert result.failed_rules[0]["risk_value"] == Rule.HIGH

==> cfripper-0.7.2.tar.gz: cfripper-0.7.2/tests/test_rules_sqs_policy_public.py <==
"""
Copyright 2018 Skyscanner Ltd

Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License.
You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed
under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
CONDITIONS OF ANY KIND, either express or implied. See the License for the
specific language governing permissions and limitations under the License.
"""


import pytest
import os
import pycfmodel

from cfripper.model.enums import RuleRisk
from cfripper.rules.SQSQueuePolicyPublicRule import SQSQueuePolicyPublicRule
from cfripper.model.utils import convert_json_or_yaml_to_dict
from cfripper.model.result import Result


class TestSQSQueuePolicyPublicRule:
    @pytest.fixture(scope="class")
    def template(self):
        dir_path = os.path.dirname(os.path.realpath(__file__))
        with open(f"{dir_path}/test_templates/sqs_policy_public.json") as cf_script:
            cf_template = convert_json_or_yaml_to_dict(cf_script.read())
        return pycfmodel.parse(cf_template)

    def test_public(self, template):
        result = Result()
        rule = SQSQueuePolicyPublicRule(None, result)

        rule.invoke(template.resources, template.parameters)

        assert not result.valid
        assert len(result.failed_rules) == 4
        assert result.failed_rules[0]["reason"] == "SQS Queue policy QueuePolicyPublic1 should not be public"
        assert result.failed_rules[1]["reason"] == "SQS Queue policy QueuePolicyPublic2 should not be public"
        assert result.failed_rules[2]["reason"] == "SQS Queue policy QueuePolicyPublic3 should not be public"
        assert result.failed_rules[3]["reason"] == "SQS Queue policy QueuePolicyPublic4 should not be public"

        assert result.failed_rules[0]["risk_value"] == RuleRisk.HIGH
